==> transmission_0.72.dfsg.orig.tar.gz: transmission-0.72.dfsg.orig/libtransmission/upnp.h <==
/******************************************************************************
 * $Id: upnp.h 1720 2007-04-15 07:36:24Z joshe $
 *
 * Copyright (c) 2006 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef TR_UPNP_H
#define TR_UPNP_H 1

typedef struct tr_upnp_s tr_upnp_t; 

tr_upnp_t * tr_upnpInit();
void        tr_upnpStart( tr_upnp_t * );
void        tr_upnpStop( tr_upnp_t * );
int         tr_upnpStatus( tr_upnp_t * );
void        tr_upnpForwardPort( tr_upnp_t *, int );
void        tr_upnpRemoveForwarding( tr_upnp_t * );
void        tr_upnpPulse( tr_upnp_t * );
void        tr_upnpClose( tr_upnp_t * );

#endif

==> transmission_0.91.dfsg.orig.tar.gz: transmission-0.91.dfsg/libtransmission/upnp.h <==
/******************************************************************************
 * $Id: upnp.h 2898 2007-08-21 20:38:34Z charles $
 *
 * Copyright (c) 2006 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#ifndef TR_UPNP_H
#define TR_UPNP_H 1

typedef struct tr_upnp_s tr_upnp_t; 

tr_upnp_t * tr_upnpInit             ( void );
void        tr_upnpStart            ( tr_upnp_t * );
void        tr_upnpStop             ( tr_upnp_t * );
int         tr_upnpStatus           ( tr_upnp_t * );
void        tr_upnpForwardPort      ( tr_upnp_t *, int );
void        tr_upnpRemoveForwarding ( tr_upnp_t * );
void        tr_upnpPulse            ( tr_upnp_t * );
void        tr_upnpClose            ( tr_upnp_t * );

#endif
